import { LinkTopic } from '../../components/link-topic';
import { HelpTopic } from '../../models/help-topic';

export function HelpConceptSystem() {
  return (
    <div className='text-justify'>
      <h1>Концептуальная схема – Система определений</h1>
      <p>
        Данный раздел вводит <b>систему определений</b> как предмет концептуализации предметных областей. Под системой
        определений понимается совокупность отдельных понятий и утверждений, а также связей между ними, задаваемых
        определениями понятий.
      </p>

      <p>
        Система определений является инструментов исследования некоторого объекта с некоторой точки зрения, выделяемой
        решаемой задачей. К такому инструменту предъявляются требования по <b>выразительной способности</b> –
        возможности различить совокупность предметных сущностей – и по отсутствию возможности толкования.
      </p>

      <p>
        Концептуальную схему часто называют <b>теорией предметной области</b>, поскольку она позволяет зафиксировать
        систему определений как аксиоматическую теорию в некотором формальном аппарате. Концептуальной моделью называют
        совокупность концептуальной схемы и функций интерпретации ее понятий в предметной области.
      </p>

      <p>
        Система определений строится на основе <b>неопределяемых понятий</b>, которым дается неформальное определение,
        называемое <b>конвенцией</b>, то есть единообразно понимаемая участниками договоренность о соотнесении
        неопределяемых понятий с сущностями или объектами в предметной области. Помимо конвенции часто задают ряд
        утверждений, связывающих неопределяемые понятия, называемых <b>аксиомами</b>.
      </p>

      <p>
        Остальным понятиям даются формальные определения с помощью некоторого одинаково понимаемого участниками способа
        экспликации. Портал поддерживает <LinkTopic text='экспликацию в родах структур' topic={HelpTopic.RSLANG} />.
        Помимо аксиом также могут приводиться дополнительные утверждения, называемые <b>теоремами</b>. Понятия, которым
        даются формальные определения называют <b>производными</b>. Следует отметить, что в родоструктурной экспликации
        к аксиомам также относят соотношения <LinkTopic text='типизации' topic={HelpTopic.RSL_TYPES} />, а к производным
        понятиям, – термы, терм-функции и предикат-функции.
      </p>

      <p>
        <b>Ядром</b> концептуальной схемы называют совокупность базовых понятий, аксиом и промежуточных производных
        понятий, необходимых для формирования выражений аксиом. Остальные понятия относят к <b>Телу</b> концептуальной
        схемы.
      </p>

      <p>
        Для достижения необходимой выразительной способности в концептуальной схеме выделяют "ключевые" понятия, которые
        дедуктивно выводят из базовых понятий последовательным выводом промежуточных понятий. Такая деятельность
        называется <b>разворачиванием</b> термов (тела теории). Используемый формальный аппарат позволяет помимо
        ключевых сформировать полное разнообразие понятий по основаниям, выделенным в ходе построения ключевых термов.
        Такие построенные разнообразия могут использоваться для формулирования решений, в частности при нормативном
        регулировании.
      </p>

      <p>
        Более подробно различные отношения между понятиями и способы построения систем определений раскрываются в
        разделе <LinkTopic text='Связи понятий' topic={HelpTopic.CC_RELATIONS} />.
      </p>
    </div>
  );
}
